@@ -1,7 +1,9 @@
-from kappadata.datasets.kd_dataset import KDDataset
 from torchvision.datasets import ImageFolder
 from torchvision.datasets.folder import default_loader
 
+from kappadata.datasets.kd_dataset import KDDataset
+
+
 class KDImageFolder(KDDataset):
     def __init__(
             self,
@@ -10,20 +12,20 @@ class KDImageFolder(KDDataset):
             target_transform=None,
             loader=default_loader,
             is_valid_file=None,
-            **kwargs,
     ):
-        super().__init__(**kwargs)
+        super().__init__()
         self.dataset = ImageFolder(
             root=root,
-            transform=transform,
             target_transform=target_transform,
             loader=loader,
             is_valid_file=is_valid_file,
         )
+        self.transform = transform
 
     # noinspection PyUnusedLocal
     def getitem_x(self, idx, ctx=None):
         x, _ = self.dataset[idx]
+        x = self.transform(x, ctx=ctx)
         return x
 
     # noinspection PyUnusedLocal
