@@ -20,12 +20,14 @@ class AddGaussianNoiseTransform(KDStochasticTransform):
             magnitude_min=magnitude_min,
             magnitude_max=magnitude_max,
         )
-        self.strength = self.og_strength = 1.
+        self.ctx_key = f"{self.ctx_prefix}.magnitude"
 
     def _scale_strength(self, factor):
-        self.strength = factor
+        self.magnitude_sampler.scale_strength(factor)
 
     def __call__(self, x, ctx=None):
         magnitude = self.magnitude_sampler.sample(self.rng)
         noise = torch.from_numpy(self.rng.normal(scale=magnitude, size=x.shape)).float()
+        if ctx is not None:
+            ctx[self.ctx_key] = magnitude
         return x + noise
